if (!window.ExampleListPerson) {
	window.ExampleListPerson = function(data) {
		data = data ? data : {};
		this.name = data.name ? data.name : null;
		this.age = data.age ? data.age : null;
		this.serialize = function() {
			var obj = {
				name: this.name,
				age: this.age
			};
			return obj;
		};
	};
}

PluginWrapper.registerPlugin('example_List', {
	name: 'List Example Plugin',
	element: {
		minSize: {width: 100, height: 100},
		defaultSize: {width: 200, height: 100},
		resizable: true,
	},
	
	propertyDialog: {
		tabs: [
			{name: 'Tab 1', children: [
				{type: 'HorizontalLayout', columnWeights: [4, 8], children: [
					{type: 'List', id: 'list',
						// height of inner list element (list of items)
						listHeight: 260,
						// height of outer list element (grey block)
						css: {height: 300},
						// enable opportunity to add and delete items
						editable: true,
						// disable opportunity to change items order
						sortable: false,
						// 'itemType' is required. It has to be defined above and must contain method "serialize"
						itemType: window.ExampleListPerson,
						// triggered when item is selected in the list
						select: function(fields, item) {
							var last = fields.list.getLastSelected();
							if (last) { // save changes to current item
								last.name = fields.name.getValue();
								last.age = fields.age.getValue();
							}
							// propagate text fields with selected item
							fields.name.setValue(item.name);
							fields.age.setValue(item.age);
						},
						// triggered when item is added in the list
						add: function(fields, item, li) {
							if (!fields.initialAdd) {
								fields.list.selectItemLi($(li));
							}
						}
					},
					{type: 'VerticalLayout', children: [
						{type: 'Label', text: 'Name'},
						{type: 'TextField', id: 'name'},
						{type: 'Label', text: 'Age'},
						{type: 'TextField', id: 'age'}
					]}
				]},
			]}
		]
	},

	openAction: function(fields, data, elem) {
		var obj, li;
		fields.list.removeAllItems();
		fields.initialAdd = true; // we do not need function "add" triggered on initial list generation
		for (var i in data.content.list) {
			obj = new window.ExampleListPerson(data.content.list[i]);
			fields.list.addItem(obj);
		}
		fields.initialAdd = false;
		fields.list.selectFirst();
	},

	applyAction: function(fields, data, elem) {
		fields.list.selectFirst(); // to save last selected item changes
		data.content.list = [];
		var list = fields.list.getValue(); // ExampleListPerson[]
		for (var i in list) {
			data.content.list.push(list[i].serialize());
		}
		data.content.emptyList = (!data.content.list.length);
	},

	loadAction: function(data) {
		if (!data.content.list) data.content.list = [
			{name: 'Joe', age: 38},
			{name: 'Michael', age: 29},
			{name: 'Helen', age: 31}
		];
		data.content.emptyList = (!data.content.list.length);
	}
});